==> pde-2.7.0.tgz: package/lib/hooks/useExperiment.js <==
import { useContext, useMemo } from 'react';
import PdeContext from '../contexts/PdeContext';
import { getPlatformStrategy } from './platformStrategies';
/**
 * Hook to use a experiment
 * @param {object} param
 * @param {string} param.experimentName
 * @param {object} param.attributes
 * @param {function} param.trackExperimentViewed
 * @param {string} [param.queryString] Test purposes only
 * @return {{variation: string}}
 */

export default function useExperiment(_temp) {
  var _ref = _temp === void 0 ? {} : _temp,
      experimentName = _ref.experimentName,
      attributes = _ref.attributes,
      trackExperimentViewed = _ref.trackExperimentViewed,
      queryString = _ref.queryString;

  var _useContext = useContext(PdeContext),
      pde = _useContext.pde;

  if (pde === null) throw new Error('[sui-pde: useExperiment] sui-pde provider is required to work');
  var variation = useMemo(function () {
    var variationName;
    var strategy = getPlatformStrategy({
      customTrackExperimentViewed: trackExperimentViewed
    });

    try {
      var forcedVariation = strategy.getForcedValue({
        key: experimentName,
        queryString: queryString
      });

      if (forcedVariation) {
        return forcedVariation;
      }

      variationName = strategy.getVariation({
        pde: pde,
        experimentName: experimentName,
        attributes: attributes
      });
      strategy.trackExperiment({
        variationName: variationName,
        experimentName: experimentName
      });
    } catch (error) {
      // eslint-disable-next-line no-console
      console.error(error);
      return null;
    }

    return variationName;
  }, [trackExperimentViewed, experimentName, queryString, pde, attributes]);
  return {
    variation: variation
  };
}

==> pde-2.19.0.tgz: package/lib/hooks/useExperiment.js <==
import { useContext, useMemo } from 'react';
import PdeContext from '../contexts/PdeContext.js';
import { getPlatformStrategy } from './common/platformStrategies.js';
/**
 * Hook to use a experiment
 * @param {object} param
 * @param {string} param.experimentName
 * @param {object} param.attributes
 * @param {function} param.trackExperimentViewed
 * @param {string} param.queryString
 * @param {string} param.adapterId Adapter id to be executed
 * @return {{variation: string}}
 */

export default function useExperiment(_temp) {
  var _ref = _temp === void 0 ? {} : _temp,
      experimentName = _ref.experimentName,
      attributes = _ref.attributes,
      trackExperimentViewed = _ref.trackExperimentViewed,
      queryString = _ref.queryString,
      adapterId = _ref.adapterId;

  var _useContext = useContext(PdeContext),
      pde = _useContext.pde;

  if (pde === null) throw new Error('[sui-pde: useExperiment] sui-pde provider is required to work');
  var variation = useMemo(function () {
    var variationName;
    var strategy = getPlatformStrategy({
      customTrackExperimentViewed: trackExperimentViewed
    });

    try {
      var forcedVariation = strategy.getForcedValue({
        key: experimentName,
        queryString: queryString
      });

      if (forcedVariation) {
        return forcedVariation;
      }

      variationName = strategy.getVariation({
        pde: pde,
        experimentName: experimentName,
        attributes: attributes,
        adapterId: adapterId
      });
      strategy.trackExperiment({
        variationName: variationName,
        experimentName: experimentName
      });
    } catch (error) {
      // eslint-disable-next-line no-console
      console.error(error);
      return null;
    }

    return variationName;
  }, [trackExperimentViewed, experimentName, queryString, pde, attributes, adapterId]);
  return {
    variation: variation
  };
}
